LinkCollector

Struct LinkCollector 

struct LinkCollector<'a, 'tcx> {
    cx: &'a mut DocContext<'tcx>,
    links: LinkCollection,
}

Fields

cx: &'a mut DocContext<'tcx>links: LinkCollection

Implementations

Source

impl<'tcx> LinkCollector<'_, 'tcx>

fn variant_field<'path>( &self, path_str: &'path str, item_id: DefId, module_id: ModId, ) -> Result<(Res, DefId), UnresolvedPath<'path>>

Given a full link, parse it as an enum struct variant.

In particular, this will return an error whenever there aren’t three full path segments left in the link.

fn resolve_path( &self, path_str: &str, ns: Namespace, item_id: DefId, module_id: ModId, ) -> Option<Res>

Convenience wrapper around doc_link_resolutions.

This also handles resolving true and false as booleans. NOTE: doc_link_resolutions knows only about paths, not about types. Associated items will never be resolved by this function.

fn resolve<'path>( &self, path_str: &'path str, ns: Namespace, disambiguator: Option<Disambiguator>, item_id: DefId, module_id: ModId, ) -> Result<Vec<(Res, Option<DefId>)>, UnresolvedPath<'path>>

Resolves a string as a path within a particular namespace. Returns an optional URL fragment in the case of variants and methods.

Source

impl LinkCollector<'_, '_>

This is the entry point for resolving an intra-doc link.

Returns true if a link could be generated from the given intra-doc information.

This is a very light version of format::href_with_root_path since we’re only interested about whether we can generate a link to an item or not.

  • If original_did is local, then we check if the item is reexported or public.
  • If original_did is not local, then we check if the crate it comes from is a direct public dependency.
fn resolve_ambiguities(&mut self)

fn verify_disambiguator( &self, path_str: &str, kind: DefKind, id: DefId, disambiguator: Option<Disambiguator>, diag_info: &DiagnosticInfo<'_>, ) -> Option<()>

fn report_disambiguator_mismatch( &self, path_str: &str, specified: Disambiguator, resolved: Res, diag_info: &DiagnosticInfo<'_>, )

fn report_rawptr_assoc_feature_gate( &self, dox: &str, ori_link: &MarkdownLinkRange, item: &Item, )

fn resolve_with_disambiguator_cached( &mut self, key: ResolutionInfo, diag: DiagnosticInfo<'_>, cache_errors: bool, ) -> Option<Vec<(Res, Option<UrlFragment>)>>

fn resolve_with_disambiguator( &mut self, key: &ResolutionInfo, diag: DiagnosticInfo<'_>, ) -> Vec<(Res, Option<DefId>)>

After parsing the disambiguator, resolve the main part of the link.